@@ -95,6 +95,13 @@ OPTIONS
       software-home         Where other components and product are located.
     OPTIONAL KEYS
       access-file           This instance access file location.
+      access-username       This instance access initial/emergency username.
+      access-password       The initial/emergency user's password.
+      access-encoding       The format in which the initial/emergency user's
+                            password is encoded.
+      access-domains        The domains from which the initial/emergency
+                            user can log in (it is acceptable to leave
+                            this blank).
       pcgi-error-log        The value of PCGI_ERROR_LOG in the pcgi resource
                             file.
       pcgi-exe              The value of PCGI_EXE in the pcgi resource file.
@@ -233,6 +240,10 @@ AUTHOR
         self.__false = ('0', 'no', 'false', 'off')
         self.__table = {
             'access-file':                  ['pwd',  None,    None,    None],
+            'access-username':              ['pwd',  '-u',    None,    None],
+            'access-password':              ['pwd',  '-p',    None,    None],
+            'access-encoding':              ['pwd',  '-e',    None,    None],
+            'access-domains':               ['pwd',  '-d',    None,    None],
             'basename':                     [None,   None,    None,    None],
             'check-interval':               ['z2',   '-i',    None,    None],
             'debug':                        ['z2',   '-D',    'flag',  None],
